import HeroSection from "./components/HeroSection";
import {
  Zap,
  TrendingUp,
  Shield,
  Users,
  Clock,
  HeadphonesIcon,
} from "lucide-react";

export default function Home() {
  return (
    <main className="min-h-screen bg-gradient-to-b from-gray-900 to-purple-900">
      <header className="bg-gray-900 shadow-md">
        <nav className="container mx-auto px-4 py-4">
          <div className="flex flex-col md:flex-row items-center justify-between">
            <div className="text-xl font-bold text-purple-300 mb-4 md:mb-0">
              AI Crypto Trading
            </div>
            <div className="flex space-x-4">
              <a
                href="#features"
                className="text-gray-300 hover:text-purple-300"
              >
                Features
              </a>
              <a href="#about" className="text-gray-300 hover:text-purple-300">
                About
              </a>
              <a
                href="#contact"
                className="text-gray-300 hover:text-purple-300"
              >
                Contact
              </a>
            </div>
          </div>
        </nav>
      </header>

      <div className="container mx-auto px-4 py-8 md:py-12">
        <h1 className="text-3xl md:text-5xl font-bold text-center mb-6 text-purple-300">
          Trade Smarter with the Power of AI: Your Personal Auto-Trading
          Solution
        </h1>
        <p className="text-lg md:text-xl text-center mb-8 md:mb-12 text-gray-300">
          Unlock a new level of trading with our AI-powered trading bot,
          designed to simplify and automate your trading journey.
        </p>

        <HeroSection />

        <section id="features" className="mb-12 md:mb-16">
          <h2 className="text-2xl md:text-3xl font-bold text-center mb-6 md:mb-8 text-purple-300">
            What We Offer
          </h2>
          <div className="grid md:grid-cols-3 gap-6 md:gap-8">
            <div className="bg-gray-800 p-4 md:p-6 rounded-lg shadow-lg">
              <Zap className="h-10 w-10 md:h-12 md:w-12 text-purple-500 mb-4" />
              <h3 className="text-lg md:text-xl font-semibold mb-2 text-purple-300">
                Automated Trading Solutions
              </h3>
              <p className="text-sm md:text-base text-gray-400">
                Sit back and let the bot trade for you! Fully automated and
                optimized to capture opportunities across different markets.
              </p>
            </div>
            <div className="bg-gray-800 p-4 md:p-6 rounded-lg shadow-lg">
              <TrendingUp className="h-10 w-10 md:h-12 md:w-12 text-purple-500 mb-4" />
              <h3 className="text-lg md:text-xl font-semibold mb-2 text-purple-300">
                Real-Time Market Analysis
              </h3>
              <p className="text-sm md:text-base text-gray-400">
                Leverages data from multiple sources to make rapid, data-driven
                decisions to help you stay ahead in volatile markets.
              </p>
            </div>
            <div className="bg-gray-800 p-4 md:p-6 rounded-lg shadow-lg">
              <Shield className="h-10 w-10 md:h-12 md:w-12 text-purple-500 mb-4" />
              <h3 className="text-lg md:text-xl font-semibold mb-2 text-purple-300">
                Risk Management and Control
              </h3>
              <p className="text-sm md:text-base text-gray-400">
                Customizable settings allow you to set risk tolerance and
                trading parameters that match your comfort level.
              </p>
            </div>
          </div>
        </section>

        <section id="about" className="mb-12 md:mb-16">
          <h2 className="text-2xl md:text-3xl font-bold text-center mb-6 md:mb-8 text-purple-300">
            Why Choose Us?
          </h2>
          <div className="grid md:grid-cols-3 gap-6 md:gap-8">
            <div className="bg-gray-800 p-4 md:p-6 rounded-lg shadow-lg">
              <Users className="h-10 w-10 md:h-12 md:w-12 text-purple-500 mb-4" />
              <h3 className="text-lg md:text-xl font-semibold mb-2 text-purple-300">
                Trained by Top Traders
              </h3>
              <p className="text-sm md:text-base text-gray-400">
                Our AI has been trained with strategies and techniques from
                leading traders, ensuring high performance and adaptive trading
                styles.
              </p>
            </div>
            <div className="bg-gray-800 p-4 md:p-6 rounded-lg shadow-lg">
              <Clock className="h-10 w-10 md:h-12 md:w-12 text-purple-500 mb-4" />
              <h3 className="text-lg md:text-xl font-semibold mb-2 text-purple-300">
                24/7 Monitoring
              </h3>
              <p className="text-sm md:text-base text-gray-400">
                The bot trades around the clock, so you never miss an
                opportunity in the fast-paced crypto market.
              </p>
            </div>
            <div className="bg-gray-800 p-4 md:p-6 rounded-lg shadow-lg">
              <HeadphonesIcon className="h-10 w-10 md:h-12 md:w-12 text-purple-500 mb-4" />
              <h3 className="text-lg md:text-xl font-semibold mb-2 text-purple-300">
                Dedicated Support
              </h3>
              <p className="text-sm md:text-base text-gray-400">
                Our team is always available to assist you with any questions or
                concerns you may have about your trading bot.
              </p>
            </div>
          </div>
        </section>

        <section id="contact" className="text-center mb-12 md:mb-16">
          <h2 className="text-2xl md:text-3xl font-bold mb-4 text-purple-300">
            Ready to Get Started?
          </h2>
          <p className="text-lg md:text-xl text-gray-300 mb-6 md:mb-8">
            Trade smarter, not harder. Let our AI trading bot enhance your
            strategy, minimize your workload, and unlock your trading potential.
          </p>
          <a
            href="#"
            className="inline-block bg-purple-600 hover:bg-purple-700 text-white font-bold py-2 px-6 rounded-full text-lg transition duration-300 ease-in-out transform hover:scale-105"
          >
            Start Your Free Trial
          </a>
        </section>
      </div>

      <footer className="bg-gray-900 text-gray-300 py-8">
        <div className="container mx-auto px-4">
          <div className="grid md:grid-cols-3 gap-8">
            <div className="mb-6 md:mb-0">
              <h3 className="text-xl font-bold mb-2">AI Crypto Trading</h3>
              <p className="text-sm md:text-base">
                Empowering traders with cutting-edge AI technology.
              </p>
            </div>
            <div className="mb-6 md:mb-0">
              <h3 className="text-xl font-bold mb-2">Quick Links</h3>
              <ul className="text-sm md:text-base">
                <li>
                  <a href="#features" className="hover:text-purple-300">
                    Features
                  </a>
                </li>
                <li>
                  <a href="#about" className="hover:text-purple-300">
                    About Us
                  </a>
                </li>
                <li>
                  <a href="#contact" className="hover:text-purple-300">
                    Contact
                  </a>
                </li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-2">Contact Us</h3>
              <p className="text-sm md:text-base">
                Email: support@aicryptotrading.com
              </p>
              <p className="text-sm md:text-base">Phone: +1 (555) 123-4567</p>
            </div>
          </div>
          <div className="border-t border-gray-800 mt-8 pt-8 text-sm text-center">
            <p>&copy; 2023 AI Crypto Trading. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </main>
  );
}
